@@ -1,3 +1,6 @@
+#!/usr/bin/env python
+# coding=utf-8
+
 import json
 import threading
 
@@ -27,6 +30,10 @@ class BinanceSocketManager(threading.Thread):
     _user_timeout = 50 * 60  # 50 minutes
 
     def __init__(self, client):
+        """
+        Intialise the BinanceSocketManager
+        :param client: Binance API client
+        """
         threading.Thread.__init__(self)
         self._client = client
 
@@ -43,18 +50,46 @@ class BinanceSocketManager(threading.Thread):
         return True
 
     def start_depth_socket(self, symbol, callback):
+        """
+        Start a websocket for symbol market depth
+        :param symbol:
+        :param callback:
+        :return:
+        """
         return self._start_socket(symbol.lower() + '@depth', callback)
 
     def start_kline_socket(self, symbol, callback):
+        """
+        Start a websocket for symbol kline data
+        :param symbol:
+        :param callback:
+        :return:
+        """
         return self._start_socket(symbol.lower() + '@kline', callback)
 
     def start_trade_socket(self, symbol, callback):
+        """
+        Start a websocket for symbol trade data
+        :param symbol:
+        :param callback:
+        :return:
+        """
         return self._start_socket(symbol.lower() + '@trade', callback)
 
     def start_ticker_socket(self, callback):
+        """
+        Start a websocket for ticker data
+        :param callback:
+        :return:
+        """
         return self._start_socket('!ticker@arr', callback)
 
     def start_user_socket(self, callback):
+        """
+        Start a websocket for user data
+        :param callback:
+        :return:
+        """
         self._user_listen_key = self._client.stream_get_listen_key()
         if self._start_socket(self._user_listen_key, callback):
             # start timer to keep socket alive
@@ -77,18 +112,41 @@ class BinanceSocketManager(threading.Thread):
         del(self._conns[path])
 
     def stop_depth_socket(self, symbol):
+        """
+        Stop the symbol depth socket
+        :param symbol:
+        :return:
+        """
         self._stop_socket(symbol.lower() + '@depth')
 
     def stop_kline_socket(self, symbol):
+        """
+        Stop the symbol kline socket
+        :param symbol:
+        :return:
+        """
         self._stop_socket(symbol.lower() + '@kline')
 
     def stop_trade_socket(self, symbol):
+        """
+        Stop the symbol trade socket
+        :param symbol:
+        :return:
+        """
         self._stop_socket(symbol.lower() + '@trade')
 
     def stop_ticker_socket(self):
+        """
+        Stop the ticker data websocket
+        :return:
+        """
         self._stop_socket('!ticker@arr')
 
     def stop_user_socket(self):
+        """
+        Stop the user data websocket
+        :return:
+        """
         if not self._user_listen_key:
             return
         self._stop_socket(self._user_listen_key)
@@ -103,6 +161,10 @@ class BinanceSocketManager(threading.Thread):
         reactor.run(installSignalHandlers=False)
 
     def close(self):
+        """
+        Stop the websocket manager and close connections
+        :return:
+        """
         reactor.stop()
 
         self.stop_user_socket()
